@@ -191,4 +191,14 @@ class LazyTestCase(TestCase):
     def testGetConvert(self):
         self.client.get('/lazy/')
         response = self.client.get('/convert/')
-        self.assertEqual(200, response.status_code)
\ No newline at end of file
+        self.assertEqual(200, response.status_code)
+        
+    def testConversionKeepsSameUser(self):
+        self.client.get('/lazy/')
+        response = self.client.post('/convert/', {
+            'username': 'demo',
+            'password1': 'password',
+            'password2': 'password',
+        })
+        self.assertEqual(1, len(User.objects.all()))
+    
\ No newline at end of file
